@@ -6,6 +6,7 @@
 #include <QUrl>
 #include <QDate>
 #include <QMap>
+#include <QSet>
 
 class QFile;
 class QIODevice;
@@ -27,7 +28,7 @@ public:
 	virtual void initSettings();
     virtual ~DataDownloader();
 	virtual QUrl getUrl() = 0;
-	virtual void updateSettingsFile(QString maxDataDate, bool updateInd = true);
+	virtual void updateSettingsFile(QString maxDate);
 	virtual void checkDataStatus();
 	virtual QString saveFile(QString channel, QIODevice *source);
 	virtual QString saveZipFile(QString channel, QIODevice *source);
@@ -39,6 +40,9 @@ public:
 	virtual void sendRecordMsg(QStringList input) = 0;
 	virtual bool isSingleXMLTVFile() { return true; }
 	virtual void splitXMLTVFile(QString filename);
+	virtual int timeZoneOffset() { return 0; }
+	virtual void clearRegionData();
+	virtual QDate getDownloadDate();
 
 signals:
 
