@@ -7,6 +7,7 @@
 #include <QLabel>
 #include <QMaemo5ValueButton>
 #include <QMaemo5TimePickSelector>
+#include <QMaemo5InformationBox>
 #include <QDebug>
 
 #include "settings.h" 
@@ -22,15 +23,18 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 	QTabWidget	*_tabwidget = new QTabWidget;
 	QWidget *_miscwidget = new QWidget;
 	QWidget *_timewidget = new QWidget;
+	QWidget *_modewidget = new QWidget;
 	QWidget *_iconwidget = new QWidget;
-	_tabwidget->addTab(_miscwidget, QString("     MISC     "));
-	_tabwidget->addTab(_timewidget, QString("     TIME     "));
-	_tabwidget->addTab(_iconwidget, QString("     ICON     "));
+	_tabwidget->addTab(_miscwidget, QString("   MISC   "));
+	_tabwidget->addTab(_timewidget, QString("   TIME   "));
+	_tabwidget->addTab(_modewidget, QString("   MODE   "));
+	_tabwidget->addTab(_iconwidget, QString("   ICON   "));
 
 	QGroupBox *orientBox = new QGroupBox("Orientation");
 	QGroupBox *remindBox = new QGroupBox("Remind Type");
 	QGroupBox *showPastBox = new QGroupBox("Past Listings");
 	QGroupBox *primeTimeBox = new QGroupBox("Prime Time");
+	QGroupBox *modeBox = new QGroupBox("Default Mode");
 	QGroupBox *iconBox = new QGroupBox("Icon Style");
 	QGroupBox *previewBox = new QGroupBox("Icon Preview");
 
@@ -45,6 +49,9 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 	QRadioButton *radio9 = new QRadioButton("Set2");
 	QRadioButton *radio10 = new QRadioButton("Set3");
 	QRadioButton *radio11 = new QRadioButton("Set4");
+	QRadioButton *radio12 = new QRadioButton("DAILY");
+	QRadioButton *radio13 = new QRadioButton("SEARCH");
+	QRadioButton *radio14 = new QRadioButton("CURRENT");
 
 	QVBoxLayout *box1 = new QVBoxLayout;
 	QVBoxLayout *box2 = new QVBoxLayout;
@@ -52,6 +59,7 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 	QVBoxLayout *box4 = new QVBoxLayout;
 	QHBoxLayout *box5 = new QHBoxLayout;
 	QHBoxLayout *box6 = new QHBoxLayout;
+	QHBoxLayout *box7 = new QHBoxLayout;
 
 	box1->addWidget(radio1);
 	box1->addWidget(radio2);
@@ -92,22 +100,30 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 	box6->addWidget(preview4);
 	previewBox->setLayout(box6);
 
+	box7->addWidget(radio12);
+	box7->addWidget(radio13);
+	box7->addWidget(radio14);
+	modeBox->setLayout(box7);
+
 	QPushButton *cancelButton = new QPushButton("CANCEL");
 	QPushButton *saveButton = new QPushButton("SAVE");
 
 	QGridLayout *grid1 = new QGridLayout;
 	QGridLayout *grid2 = new QGridLayout;
 	QGridLayout *grid3 = new QGridLayout;
+	QGridLayout *grid4 = new QGridLayout;
 	grid1->addWidget(orientBox, 0, 0);
 	grid1->addWidget(remindBox, 0, 1);
 	grid2->addWidget(showPastBox, 0, 0);
 	grid2->addWidget(primeTimeBox, 0, 1);
 	grid3->addWidget(iconBox, 0, 0);
 	grid3->addWidget(previewBox, 1, 0);
+	grid4->addWidget(modeBox, 0, 0);
 
 	_miscwidget->setLayout(grid1);
 	_timewidget->setLayout(grid2);
 	_iconwidget->setLayout(grid3);
+	_modewidget->setLayout(grid4);
 
 	QVBoxLayout *vlayout = new QVBoxLayout;
 	QHBoxLayout *hlayout = new QHBoxLayout;
@@ -129,6 +145,9 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 	connect(radio9, SIGNAL(clicked()), this, SLOT(setIconSet2()));
 	connect(radio10, SIGNAL(clicked()), this, SLOT(setIconSet3()));
 	connect(radio11, SIGNAL(clicked()), this, SLOT(setIconSet4()));
+	connect(radio12, SIGNAL(clicked()), this, SLOT(setDailyMode()));
+	connect(radio13, SIGNAL(clicked()), this, SLOT(setSearchMode()));
+	connect(radio14, SIGNAL(clicked()), this, SLOT(setCurrentMode()));
 	connect(startTimeSelector, SIGNAL(clicked()), this, SLOT(setStartPrimeTime()));
 	connect(endTimeSelector, SIGNAL(clicked()), this, SLOT(setEndPrimeTime()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(cancel()));
@@ -180,6 +199,22 @@ MiscSettingsWindow::MiscSettingsWindow(QMainWindow* parent) : SettingsWindow(par
 		setIconSet1();
 		radio8->setChecked(true);  // default is set1
 	}
+
+	if(getDefaultMode() == "SEARCHMODE") 
+	{
+		setSearchMode();
+		radio13->setChecked(true);
+	}
+	else if(getDefaultMode() == "CURRENTLISTINGMODE") 
+	{
+		setDefaultMode("CURRENTLISTINGMODE");
+		radio14->setChecked(true);
+	}
+	else 
+	{
+		setDailyMode();
+		radio12->setChecked(true);  // default is DAILYMODE
+	}
 }
 
 void MiscSettingsWindow::setLandscape() { setOrientation("LANDSCAPE"); }
@@ -195,6 +230,14 @@ void MiscSettingsWindow::setIconSet1() { setIconSet("SET1"); }
 void MiscSettingsWindow::setIconSet2() { setIconSet("SET2"); }
 void MiscSettingsWindow::setIconSet3() { setIconSet("SET3"); }
 void MiscSettingsWindow::setIconSet4() { setIconSet("SET4"); }
+void MiscSettingsWindow::setDailyMode() { setDefaultMode("DAILYMODE"); }
+void MiscSettingsWindow::setSearchMode() { setDefaultMode("SEARCHMODE"); }
+void MiscSettingsWindow::setCurrentMode() 
+{ 
+	QMaemo5InformationBox::information(this, "<font color=#000000><b>Ensure you have set some channels as favourite for initial selection</font>" , 
+																											QMaemo5InformationBox::DefaultTimeout);
+	setDefaultMode("CURRENTLISTINGMODE"); 
+}
 
 void MiscSettingsWindow::setIconSet(QString iconset) 
 { 
