@@ -24,7 +24,7 @@ public:
 	virtual void setInput(DownloadInput d);
 	virtual QString finishedDownload(QString channel, QIODevice *source);
 	void sendRecordMsg(QStringList data);
-	virtual int timeZoneOffset() { return -1; } // return -1 since data is generated in belgium which is 1 hr ahead of UK
+	virtual int timeZoneOffset() { return 0; /*-1;*/ } // return -1 since data is generated in belgium which is 1 hr ahead of UK
 
 signals:
 
